# extension module
from extension import Template, Syntax, setnegativedefaults
import spssaux, DisplayDict

helptext="""Display a codebook for the active dataset or write the codebook to a file.

CODEBOOK [variable list]
[/OPTIONS ALPHAORDER=YES|NO [MAXWIDTH=value]]
[/PRINT MAXWIDTH VALUELABELS ATTRIBUTES MEASLEVEL 
VARTYPE FORMAT MISSING
STATISTICS=NONE CATS ALL]
[/OUTFILE NAME=filespec]
[/HELP]

Example:
CODEBOOK x to y /PRINT MEASLEVEL STATISTICS=CATS.

If a variable list is given, only those variables are included.

For ALPHAORDER,the value can be set to true or false, yes, or no and defaults to True
For VALUELABELS, ATTRIBUTES MEASLEVEL, VARTYPE, FORMAT, and MISSING,
if any is listed, only those properties in this list are included.  
Otherwise all are included.

MAXWIDTH defaults to the SPSS setting but can be used 
to set the width of the display explicitly.

STATISTICS=NONE, the default, displays no statistics
CATS displays value counts for categorical variables 
and any labeled values of scale variables and
means for scale variables.  It also displays the number of 
valid values for all variables.
ALL displays value counts for all variables as well as the other information.

/OUTFILE writes the codebook to a text file instead of displaying it in the viewer.

/HELP displays this text and does nothing else."""

def Run(args):
    """Execute the CODEBOOK command"""
    
    
    ###print args   #debug
    args = args[args.keys()[0]]
    ###print args['OPTIONS']
    #    try:
    #       variables = args[''][0]['TOKENLIST']  # optional variable list
    #except:
    #        variables = None
    
    # define the OPTIONS subcommand syntax
    oobj = Syntax([
        Template("", subc="", var="variables", ktype="existingvarlist", islist=True),
        Template("ALPHAORDER", subc="OPTIONS", ktype="bool"),
        Template("VALUELABELS", subc="PRINT",  ktype="bool"),
        Template("MEASLEVEL", subc="PRINT", ktype="bool"),
        Template("ATTRIBUTES",  subc="PRINT", ktype="bool"),
        Template("FORMAT",  subc="PRINT", ktype="bool"),
        Template("VARTYPE", subc="PRINT",  ktype="bool"),
        Template("MISSING",  subc="PRINT", ktype="bool"),
        Template("MAXWIDTH",  subc="OPTIONS", ktype="int", vallist=[40, 255]),
        Template("STATISTICS", subc="PRINT", var="stats", ktype="str", vallist = ["none", "cats","all"]),
        Template("NAME", subc="OUTFILE", var = "outfile", ktype="literal") ])
    
    choices = set(['valuelabels','measlevel','attributes','format','vartype','missing'])

    if args.has_key("HELP"):
        print helptext
    else:
        oobj.parsecmd(args, vardict = spssaux.VariableDict())
        setnegativedefaults(choices, oobj.parsedparams)
        #for item in args.get("OPTIONS"):
        #    print item
         #   oobj.parseitem(item)
        
        DisplayDict.dictionary(**oobj.parsedparams)
